==> libkml_1.1.0.orig.tar.gz: libkml-1.1.0/src/kml/base/version.cc <==
// Copyright 2009, Google Inc. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//  1. Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//  2. Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//  3. Neither the name of Google Inc. nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
// EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
// OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
// ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// This file contains the implementation of the Version class.  The key purpose
// is to "bake" the values of the LIBKML_*_VERSION #defines into the library.

#include "kml/base/version.h"
#include "kml/base/string_util.h"

namespace kmlbase {

// static
std::string Version::GetString() {
  return ToString(get_major()) + "." + ToString(get_minor()) + "." +
         ToString(get_micro());
}

// static
bool Version::IsCompat(int major, int minor, int micro) {
  return major == get_major() && minor >= get_minor();
}

// static
int Version::get_major() {
  return LIBKML_MAJOR_VERSION;
}

// static
int Version::get_minor() {
  return LIBKML_MINOR_VERSION;
}

// static
int Version::get_micro() {
  return LIBKML_MICRO_VERSION;
}

}  // end namespace kmlbase

==> libkml_1.3.0.orig.tar.gz: libkml-1.3.0/src/kml/base/version.cc <==
// Copyright 2009, Google Inc. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//  1. Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//  2. Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//  3. Neither the name of Google Inc. nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
// EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
// OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
// ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// This file contains the implementation of the Version class.  The key purpose
// is to "bake" the values of the LIBKML_*_VERSION #defines into the library.

#include "kml/base/version.h"
#include "kml/base/string_util.h"

namespace kmlbase {

// static
string Version::GetString() {
  return ToString(get_major()) + "." + ToString(get_minor()) + "." +
         ToString(get_micro());
}

// static
bool Version::IsCompat(int major, int minor, int micro) {
  return major == get_major() && minor >= get_minor();
}

// static
int Version::get_major() {
  return LIBKML_MAJOR_VERSION;
}

// static
int Version::get_minor() {
  return LIBKML_MINOR_VERSION;
}

// static
int Version::get_micro() {
  return LIBKML_MICRO_VERSION;
}

}  // end namespace kmlbase
